/*
 * Copyright (c) 2005-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 *    
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *    
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Nokia Corporation nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *    SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *    
 *    Description:  
 */

#ifndef __HANDLER_APPVIEW_H__
#define __HANDLER_APPVIEW_H__


#include <coecntrl.h>
#include "Common.h"

/*! 
  @class CHandlerAppView
  
  @discussion An instance of the Application View object for the handler 
  example application
  */
class CHandlerAppView : public CCoeControl
    {
public:

/*!
  @function NewL
   
  @discussion Create a CHandlerAppView object, which will draw itself to aRect
  @param aRect the rectangle this view will be drawn to
  @result a pointer to the created instance of CHandlerAppView
  */
    static CHandlerAppView* NewL(const TRect& aRect);

/*!
  @function NewLC
   
  @discussion Create a CHandlerAppView object, which will draw itself to aRect
  @param aRect the rectangle this view will be drawn to
  @result a pointer to the created instance of CHandlerAppView
  */
    static CHandlerAppView* NewLC(const TRect& aRect);


/*!
  @function ~CHandlerAppView
  
  @discussion Destroy the object and release all memory objects
  */
     ~CHandlerAppView();


public:  // from CCoeControl
/*!
  @function Draw
  
  @discussion Draw this CHandlerAppView to the screen
  @param aRect the rectangle of this view that needs updating
  */
    void Draw(const TRect& aRect) const;

public:

    void SetFileData(TFileName& aFileName, TDes8& aData);  

private:

/*!
  @function ConstructL
  
  @discussion  Perform the second phase construction of a CHandlerAppView object
  @param aRect the rectangle this view will be drawn to
  */
    void ConstructL(const TRect& aRect);

/*!
  @function CHandlerAppView
  
  @discussion Perform the first phase of two phase construction 
  */
    CHandlerAppView();
    
    void SizeChanged();

private:
    
    TFileName iName;
    TBuf<KTextLengthToRead> iData;    
    
    };


#endif // __HANDLER_APPVIEW_H__
