/*
 * Copyright (c) 2005-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 *    
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *    
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Nokia Corporation nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *    SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *    
 *    Description:  
 */

#ifndef __TESTAPP_DOCUMENT_H__
#define __TESTAPP_DOCUMENT_H__

#include <akndoc.h>

// Forward declarations
class CTestAppAppUi;
class CEikApplication;

/*!
  @class CTestAppDocument

  @discussion An instance of class CTestAppDocument is the Document part of the AVKON
  application framework for the TestApp example application
  */
class CTestAppDocument : public CAknDocument
    {
public:

/*!
  @function NewL

  @discussion Construct a CTestAppDocument for the AVKON application aApp
  using two phase construction, and return a pointer to the created object
  @param aApp application creating this document
  @result a pointer to the created instance of CTestAppDocument
  */
    static CTestAppDocument* NewL(CEikApplication& aApp);

/*!
  @function NewLC

  @discussion Construct a CTestAppDocument for the AVKON application aApp
  using two phase construction, and return a pointer to the created object
  @param aApp application creating this document
  @result a pointer to the created instance of CTestAppDocument
  */
    static CTestAppDocument* NewLC(CEikApplication& aApp);

/*!
  @function ~CTestAppDocument

  @discussion Destroy the object and release all memory objects
  */
    ~CTestAppDocument();

public: // from CAknDocument
/*!
  @function CreateAppUiL

  @discussion Create a CTestAppAppUi object and return a pointer to it
  @result a pointer to the created instance of the AppUi created
  */
    CEikAppUi* CreateAppUiL();

private:

/*!
  @function ConstructL

  @discussion Perform the second phase construction of a CTestAppDocument object
  */
    void ConstructL();

/*!
  @function CTestAppDocument

  @discussion Perform the first phase of two phase construction
  @param aApp application creating this document
  */
    CTestAppDocument(CEikApplication& aApp);

    };


#endif // __TESTAPP_DOCUMENT_H__
